
#ifndef KGUIADDONS_EXPORT_H
#define KGUIADDONS_EXPORT_H

#ifdef KGUIADDONS_STATIC_DEFINE
#  define KGUIADDONS_EXPORT
#  define KGUIADDONS_NO_EXPORT
#else
#  ifndef KGUIADDONS_EXPORT
#    ifdef KF6GuiAddons_EXPORTS
        /* We are building this library */
#      define KGUIADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KGUIADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KGUIADDONS_NO_EXPORT
#    define KGUIADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KGUIADDONS_DECL_DEPRECATED
#  define KGUIADDONS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KGUIADDONS_DECL_DEPRECATED_EXPORT
#  define KGUIADDONS_DECL_DEPRECATED_EXPORT KGUIADDONS_EXPORT KGUIADDONS_DECL_DEPRECATED
#endif

#ifndef KGUIADDONS_DECL_DEPRECATED_NO_EXPORT
#  define KGUIADDONS_DECL_DEPRECATED_NO_EXPORT KGUIADDONS_NO_EXPORT KGUIADDONS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KGUIADDONS_NO_DEPRECATED
#    define KGUIADDONS_NO_DEPRECATED
#  endif
#endif
#include <kguiaddons_version.h>

#define KGUIADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KGUIADDONS_NO_DEPRECATED) && !defined(KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KGUIADDONS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KGUIADDONS_NO_DEPRECATED_WARNINGS) && !defined(KGUIADDONS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KGUIADDONS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KGUIADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KGUIADDONS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KGUIADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KGUIADDONS_NO_DEPRECATED)
#  undef KGUIADDONS_DEPRECATED
#  define KGUIADDONS_DEPRECATED_EXPORT KGUIADDONS_EXPORT
#  define KGUIADDONS_DEPRECATED_NO_EXPORT KGUIADDONS_NO_EXPORT
#elif defined(KGUIADDONS_NO_DEPRECATED_WARNINGS)
#  define KGUIADDONS_DEPRECATED
#  define KGUIADDONS_DEPRECATED_EXPORT KGUIADDONS_EXPORT
#  define KGUIADDONS_DEPRECATED_NO_EXPORT KGUIADDONS_NO_EXPORT
#else
#  define KGUIADDONS_DEPRECATED KGUIADDONS_DECL_DEPRECATED
#  define KGUIADDONS_DEPRECATED_EXPORT KGUIADDONS_DECL_DEPRECATED_EXPORT
#  define KGUIADDONS_DEPRECATED_NO_EXPORT KGUIADDONS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KGUIADDONS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KGUIADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KGUIADDONS_NO_DEPRECATED
#  define KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KGUIADDONS_VERSION
#endif
#ifdef KGUIADDONS_NO_DEPRECATED_WARNINGS
#  define KGUIADDONS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KGUIADDONS_DEPRECATED_WARNINGS_SINCE
#  ifdef KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KGUIADDONS_DEPRECATED_WARNINGS_SINCE KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KGUIADDONS_DEPRECATED_WARNINGS_SINCE KGUIADDONS_VERSION
#  endif
#endif

#ifndef KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KGUIADDONS_DEPRECATED
#  define KGUIADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KGUIADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KGUIADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KGUIADDONS_DEPRECATED_WARNINGS_SINCE >= 0x60300
#  define KGUIADDONS_DEPRECATED_VERSION_6_3(text) KGUIADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KGUIADDONS_DEPRECATED_VERSION_6_3(text)
#endif

#if KGUIADDONS_DEPRECATED_WARNINGS_SINCE >= 0x60c00
#  define KGUIADDONS_DEPRECATED_VERSION_6_12(text) KGUIADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KGUIADDONS_DEPRECATED_VERSION_6_12(text)
#endif

#if KGUIADDONS_DEPRECATED_WARNINGS_SINCE >= 0x61600
#  define KGUIADDONS_DEPRECATED_VERSION_6_22(text) KGUIADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KGUIADDONS_DEPRECATED_VERSION_6_22(text)
#endif
#define KGUIADDONS_DEPRECATED_VERSION_6(minor, text)      KGUIADDONS_DEPRECATED_VERSION_6_##minor(text)
#define KGUIADDONS_DEPRECATED_VERSION(major, minor, text) KGUIADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KGUIADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGUIADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KGUIADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KGUIADDONS_DEPRECATED_VERSION(major, minor, text)
#  define KGUIADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGUIADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KGUIADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KGUIADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KGUIADDONS_EXPORT_H */
